/***********************************************************************************
 * QGLE - A Graphical Interface to GLE                                             *
 * Copyright (C) 2006  A. S. Budden & J. Struyf                                    *
 *                                                                                 *
 * This program is free software; you can redistribute it and/or                   *
 * modify it under the terms of the GNU General Public License                     *
 * as published by the Free Software Foundation; either version 2                  *
 * of the License, or (at your option) any later version.                          *
 *                                                                                 *
 * This program is distributed in the hope that it will be useful,                 *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                  *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                   *
 * GNU General Public License for more details.                                    *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License               *
 * along with this program; if not, write to the Free Software                     *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA. *
 *                                                                                 *
 * Also add information on how to contact you by electronic and paper mail.        *
 ***********************************************************************************/

#include "consolewindow.h"

#include <iostream>

using namespace std;

ConsoleWindow::ConsoleWindow(QWidget* parent, QSplitter* splitter) : QTextEdit(parent), output(this) {
	QFont font;
	font.setFamily("Courier");
	font.setFixedPitch(true);
	font.setPointSize(10);
	setFont(font);
	setReadOnly(true);
	splitWindow = splitter;
}

ConsoleWindow::~ConsoleWindow() {
}

void ConsoleWindow::hideTriggered() {
	autoShowSize = height();
	QWidget* first = splitWindow->widget(0);
	QList<int> splitSizes;
	splitSizes.append(first->height());
	splitSizes.append(0);
	splitWindow->setSizes(splitSizes);
}

void ConsoleWindow::shouldAutoShow() {
	if (output.getExitCode() != 0) {
		QWidget* first = splitWindow->widget(0);
		QList<int> splitSizes;
		splitSizes.append(first->height());
		if (autoShowSize != 0) {
			splitSizes.append(autoShowSize);
		} else {
			splitSizes.append(75);
		}
		splitWindow->setSizes(splitSizes);
	}
}

void ConsoleWindow::println(const QString& str) {
	append(str);
}

void ConsoleWindow::contextMenuEvent(QContextMenuEvent * e) {
	QMenu *menu = createStandardContextMenu();
	menu->addAction(getHideAction());
	menu->exec(e->globalPos());
	delete menu;
}

ConsoleWindowOutput::ConsoleWindowOutput(ConsoleWindow* parent) {
	parentWindow = parent;
}

ConsoleWindowOutput::~ConsoleWindowOutput() {
}

void ConsoleWindowOutput::println() {
}

void ConsoleWindowOutput::println(const char* str) {
	parentWindow->append(QString(str));
}

void ConsoleWindowOutput::error(GLEErrorMessage* msg) {
	QString file = msg->getFile();
	QString abbrev = msg->getLineAbbrev();
	abbrev.replace('<', "&lt;");
	abbrev.replace('>', "&gt;");
	QString line = QString("%1").arg(msg->getLine());
	QString fline = QString(">> <b>%1</b> (%2)").arg(file).arg(msg->getLine());
	if (abbrev.length() > 0) {
		abbrev = QString(" <font color=\"#0000FF\">|</font>%1<font color=\"#0000FF\">|</font>").arg(abbrev);
	}
	parentWindow->append(fline+abbrev);
	if (msg->getColumn() != -1) {
		QString point = ">> ";
		int nbspc = file.length() + line.length() + 4 + msg->getColumn() - msg->getDelta();
		for (int i = 0; i < nbspc; i++) {
			point += "&nbsp;";
		}
		point += "<font color=\"#FF0000\">^</font>";
		parentWindow->append(point);
	}
}

