/***********************************************************************************
 * QGLE - A Graphical Interface to GLE                                             *
 * Copyright (C) 2006  A. S. Budden & J. Struyf                                    *
 *                                                                                 *
 * This program is free software; you can redistribute it and/or                   *
 * modify it under the terms of the GNU General Public License                     *
 * as published by the Free Software Foundation; either version 2                  *
 * of the License, or (at your option) any later version.                          *
 *                                                                                 *
 * This program is distributed in the hope that it will be useful,                 *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                  *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                   *
 * GNU General Public License for more details.                                    *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License               *
 * along with this program; if not, write to the Free Software                     *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA. *
 *                                                                                 *
 * Also add information on how to contact you by electronic and paper mail.        *
 ***********************************************************************************/

#include "propertyeditor.h"
#include "variantdelegate.h"
#include <QtDebug>
#include "qgle_statics.h"
#include "drawingobject.h"
#include "circle.h"


GLEPropertyEditor::GLEPropertyEditor(QWidget *parent)
	: QTableView(parent)
{
	hasModel = false;
}

void GLEPropertyEditor::propertyChanged(const QModelIndex &index, const QModelIndex&)
{
	if (hasModel)
	{
		GLEDrawingObjectProperty prop;
		prop = model->getFullProperty(index);
		qDebug() << "Changed property: " << prop.description << " = " << prop.value;
		QGLE::flushIO();
		GLEDrawingObject *obj;
		foreach(obj, objects)
		{
			obj->setProperty(prop.index, prop.value);
		}

		emit propertiesHaveChanged();

	}
}

void GLEPropertyEditor::objectsSelected(QList<GLEDrawingObject *> objs)
{
	objects = objs;

	bool first = true;
	GLEDrawingObject *obj;

	QSet<int> propertySet;
	foreach(obj, objs)
	{
		if (obj->isSelected())
		{
			if (first)
			{
				propertySet = obj->getValidProperties();
			}
			else
			{
				first = false;
				propertySet.intersect(obj->getValidProperties());
			}
		}
	}

	// propertySet now contains a list of properties that are
	// common to each object
	QList<GLEDrawingObjectProperty> properties;

	PropertyDescriptor thisProperty;
	GLEDrawingObjectProperty prop;

	int index;
	foreach(index, propertySet)
	{
		thisProperty = objects[0]->getPropertyDescription(index);
		prop.index = index;
		prop.description = thisProperty.description;
		prop.value = getPropertyValue(index, objs);
		prop.validValues = thisProperty.validValues;
		properties.append(prop);
	}

	if (hasModel)
		delete(model);

	model = new GLEPropertyModel(properties, this);
	connect(model, SIGNAL(dataChanged(QModelIndex, QModelIndex)),
			this, SLOT(propertyChanged(QModelIndex, QModelIndex)));
	hasModel = true;
	setModel(model);
	setItemDelegate(new VariantDelegate(this));
	setSelectionBehavior(QAbstractItemView::SelectRows);
	setSelectionMode(QAbstractItemView::NoSelection);

}

QVariant GLEPropertyEditor::getPropertyValue(int index, QList<GLEDrawingObject *> objs)
{
	// Find the value.  This involves iterating through all the
	// objects and identifying whether they all have the same value.
	// If not, return a QVariant::List containing a single entry of the
	// appropriate type.

	QVariant value, compare;
	value = objs[0]->getProperty(index);
	int i;

	for(i=1;i<objs.size();i++)
	{
		compare = objs[i]->getProperty(index);
		if (compare != value)
		{
			QList<QVariant> blank;
			blank.append(QVariant(value.type()));
			value = QVariant(blank);
			break;
		}
	}

	return(value);
}
